==> haskell-yesod-form-1.4.7.1-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-form.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-form
version: 1.4.7.1
id: yesod-form-1.4.7.1-7xQzNXEsFo38Pyeeyl4Owr
key: yesod-form-1.4.7.1-7xQzNXEsFo38Pyeeyl4Owr
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currntly it provides only Summernote support).
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Form Yesod.Form.Types Yesod.Form.Functions
    Yesod.Form.Bootstrap3 Yesod.Form.Input Yesod.Form.Fields
    Yesod.Form.Jquery Yesod.Form.Nic Yesod.Form.MassInput
    Yesod.Form.I18n.English Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Swedish Yesod.Form.I18n.German
    Yesod.Form.I18n.French Yesod.Form.I18n.Norwegian
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Russian Yesod.Form.I18n.Dutch
abi: 780119da91a000328914937f83d3f99b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-form-1.4.7.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-form-1.4.7.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/yesod-form-1.4.7.1
hs-libraries: HSyesod-form-1.4.7.1-7xQzNXEsFo38Pyeeyl4Owr
depends:
    aeson-0.11.2.0-KYo3VjEYbuTH5av5CAe0oK
    attoparsec-0.13.0.2-9hiBNMll4LoGE6dCvh31fM base-4.9.0.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    blaze-html-0.8.1.1-BhhXJch8Gg8D1ETUvb8oFp
    blaze-markup-0.7.0.3-6iLNhqMnSkpL7LEeNEW58d
    byteable-0.1.1-15aIBCArSOBEnGxArzrDTM bytestring-0.10.8.1
    containers-0.5.7.1 data-default-0.7.0-IqRn9W8OvmaDkzgIvCHqmo
    email-validate-2.2.0-J3v76v45oNvKcLCS6QdvG9
    network-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
    persistent-2.5-3p0d6jAlABZ6OthfRE6ZeY
    resourcet-1.1.7.4-5MzcrbA8GQD6CRuZwV7nMM
    semigroups-0.18.1-ESRONlmV7qgKe0wL9ZoBKD
    shakespeare-2.0.8.2-7ph12ePSh8pAY3kS6WE5fp
    template-haskell-2.11.0.0 text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    time-1.6.0.1 transformers-0.5.2.0
    wai-3.2.1.1-FhGbGXgEdLG73fMsfll74t
    xss-sanitize-0.3.5.7-3mfUUnu7pVh396oYmaX8pV
    yesod-core-1.4.20.2-6YDVO83zPL4WVUJgroQqn
    yesod-persistent-1.4.0.5-3A5PSARHlBADRGoTtfs11h
haddock-interfaces: /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html: /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-form-1.4.7.1-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-form.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-form
version: 1.4.7.1
id: yesod-form-1.4.7.1-LmIjkgFvHob5G8nwRxgBXn
key: yesod-form-1.4.7.1-LmIjkgFvHob5G8nwRxgBXn
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currntly it provides only Summernote support).
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Form Yesod.Form.Types Yesod.Form.Functions
    Yesod.Form.Bootstrap3 Yesod.Form.Input Yesod.Form.Fields
    Yesod.Form.Jquery Yesod.Form.Nic Yesod.Form.MassInput
    Yesod.Form.I18n.English Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Swedish Yesod.Form.I18n.German
    Yesod.Form.I18n.French Yesod.Form.I18n.Norwegian
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Russian Yesod.Form.I18n.Dutch
abi: 1da08da12b88fb5be9b844e95a1e166e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-form-1.4.7.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-form-1.4.7.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/yesod-form-1.4.7.1
hs-libraries: HSyesod-form-1.4.7.1-LmIjkgFvHob5G8nwRxgBXn
depends:
    aeson-0.11.2.0-FbOoMAnyGWNAFaN63GUEkg
    attoparsec-0.13.0.2-HXBOMFQRhhb7ZddTjkE24r base-4.9.0.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    blaze-html-0.8.1.1-BhhXJch8Gg8D1ETUvb8oFp
    blaze-markup-0.7.0.3-6iLNhqMnSkpL7LEeNEW58d
    byteable-0.1.1-15aIBCArSOBEnGxArzrDTM bytestring-0.10.8.1
    containers-0.5.7.1 data-default-0.7.1-JFxCZPlwLrgBdoJyXvU7p7
    email-validate-2.2.0-H9iaB5KOqjvDUVDluQzp2w
    network-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
    persistent-2.5-JdSBQivcxHe6inpcQQBCDk
    resourcet-1.1.7.4-5MzcrbA8GQD6CRuZwV7nMM
    semigroups-0.18.1-ESRONlmV7qgKe0wL9ZoBKD
    shakespeare-2.0.8.2-IeBxiVQptYf97shf6OiTqG
    template-haskell-2.11.0.0 text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    time-1.6.0.1 transformers-0.5.2.0
    wai-3.2.1.1-FhGbGXgEdLG73fMsfll74t
    xss-sanitize-0.3.5.7-C1MiH4zW4DrL9t6MKGz2lY
    yesod-core-1.4.20.2-3PvI8VLyjR77tcZpa6GDKN
    yesod-persistent-1.4.0.5-2kaxBryM7FE9HdyIMPX1TU
haddock-interfaces: /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html: /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
